@@ -51,7 +51,7 @@
 #include "catalogitem.h"
 #include "linguistimport.h"
 
-K_EXPORT_COMPONENT_FACTORY( kbabel_linguistimport, KGenericFactory<LinguistImportPlugin> )
+K_EXPORT_COMPONENT_FACTORY( kbabel_linguistimport, KGenericFactory<LinguistImportPlugin> ( "kbabellinguistimportfilter" ) )
 
 using namespace KBabel;
 
