@@ -17,18 +17,23 @@
 **
 ***************************************************************************/
 
-#include <klocale.h>
-#include <kiconloader.h>
-#include <kstatusbar.h>
-#include <kkeydialog.h>
-#include <kedittoolbar.h>
-#include <kstdaction.h>
-#include <ksqueezedtextlabel.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
-#include <kuserprofile.h>
+#include <ktexteditor/document.h>
+#include <ktexteditor/editinterface.h>
+#include <ktexteditor/view.h>
 #include <kdebug.h>
+#include <kedittoolbar.h>
+#include <kencodingfiledialog.h>
+#include <kiconloader.h>
+#include <kkeydialog.h>
+#include <klibloader.h>
+#include <klocale.h>
+#include <kmessagebox.h>
+#include <kparts/componentfactory.h>
+#include <ksqueezedtextlabel.h>
+#include <kstatusbar.h>
+#include <kstdaction.h>
 #include <ktrader.h>
+#include <kuserprofile.h>
 
 #include "kompare_part.h"
 #include "komparenavtreepart.h"
@@ -46,7 +51,7 @@ KompareShell::KompareShell()
 	m_textViewWidget( 0 )
 {
 	if ( !initialGeometrySet() )
-	resize( 700, 480 );
+	resize( 800, 480 );
 
 	// set the shell's ui resource file
 	setXMLFile("kompareui.rc");
@@ -69,7 +74,7 @@ KompareShell::KompareShell()
 #endif
 	if ( offers.count() == 0 )
 	{
-		KMessageBox::error(this, i18n( "Could not find our KompareViewPart!" ) );
+		KMessageBox::error(this, i18n( "Could not find our KompareViewPart." ) );
 		exit(1);
 	}
 
@@ -98,7 +103,7 @@ KompareShell::KompareShell()
 	{
 		// if we couldn't load our Part, we exit since the Shell by
 		// itself can't do anything useful
-		KMessageBox::error(this, i18n( "Could not load our KompareViewPart!" ) );
+		KMessageBox::error(this, i18n( "Could not load our KompareViewPart." ) );
 		exit(2);
 	}
 
@@ -106,7 +111,7 @@ KompareShell::KompareShell()
 	offers = KTrader::self()->query( "text/x-diff", "KParts/ReadOnlyPart", "'Kompare/NavigationPart' in ServiceTypes", QString::null );
 	if ( offers.count() == 0 )
 	{
-		KMessageBox::error(this, i18n( "Could not find our KompareNavigationPart!" ) );
+		KMessageBox::error(this, i18n( "Could not find our KompareNavigationPart." ) );
 		exit(3);
 	}
 
@@ -130,13 +135,13 @@ KompareShell::KompareShell()
 	{
 		// if we couldn't load our Part, we exit since the Shell by
 		// itself can't do anything useful
-		KMessageBox::error(this, i18n( "Could not load our KompareNavigationPart!" ) );
+		KMessageBox::error(this, i18n( "Could not load our KompareNavigationPart." ) );
 		exit(4);
 	}
 
 	// Hook up the inter part communication
-	connect( m_viewPart, SIGNAL( modelsChanged(const QPtrList<Diff2::DiffModel>*) ),
-	         m_navTreePart, SLOT( slotModelsChanged( const QPtrList<Diff2::DiffModel>*) ) );
+	connect( m_viewPart, SIGNAL( modelsChanged(const Diff2::DiffModelList*) ),
+	         m_navTreePart, SLOT( slotModelsChanged( const Diff2::DiffModelList*) ) );
 
 	connect( m_viewPart, SIGNAL( kompareInfo(Kompare::Info*) ),
 	         m_navTreePart, SLOT( slotKompareInfo(Kompare::Info*) ) );
@@ -187,6 +192,7 @@ void KompareShell::openDiff(const KURL& url)
 {
 	kdDebug(8102) << "Url = " << url.prettyURL() << endl;
 	m_diffURL = url;
+	m_viewPart->setEncoding( "Default" );
 	m_viewPart->openDiff( url );
 }
 
@@ -201,6 +207,7 @@ void KompareShell::openStdin()
 
 	file.close();
 
+	m_viewPart->setEncoding( "Default" );
 	m_viewPart->openDiff( diff );
 
 }
@@ -210,6 +217,7 @@ void KompareShell::compare(const KURL& source,const KURL& destination )
 	m_sourceURL = source;
 	m_destinationURL = destination;
 
+	m_viewPart->setEncoding( "Default" );
 	m_viewPart->compare( source, destination );
 }
 
@@ -218,6 +226,7 @@ void KompareShell::blend( const KURL& url1, const KURL& diff )
 	m_sourceURL = url1;
 	m_destinationURL = diff;
 
+	m_viewPart->setEncoding( "Default" );
 	m_viewPart->openDirAndDiff( url1, diff );
 }
 
@@ -239,6 +248,7 @@ void KompareShell::setupActions()
 	setStandardToolBarMenuEnabled(true);
 	m_showTextView = new KToggleAction( i18n("Show T&ext View"), 0, this, SLOT(slotShowTextView()),
 	                                  actionCollection(), "options_show_text_view" );
+        m_showTextView->setCheckedState(i18n("Hide T&ext View"));
 
 	KStdAction::keyBindings(this, SLOT(optionsConfigureKeys()), actionCollection());
 	KStdAction::configureToolbars(this, SLOT(optionsConfigureToolbars()), actionCollection());
@@ -284,6 +294,7 @@ void KompareShell::slotSetStatusBarText( const QString& text )
 
 void KompareShell::setCaption( const QString& caption )
 {
+//	kdDebug() << kdBacktrace();
 	KParts::DockMainWindow::setCaption( caption, m_viewPart->isModified() );
 }
 
@@ -344,6 +355,7 @@ void KompareShell::readProperties(KConfig* config)
 
 void KompareShell::slotFileOpen()
 {
+	// FIXME: use different filedialog which gets encoding
 	KURL url = KFileDialog::getOpenURL( QString::null, "text/x-diff", this );
 	if( !url.isEmpty() ) {
 		KompareShell* shell = new KompareShell();
@@ -355,9 +367,9 @@ void KompareShell::slotFileOpen()
 
 void KompareShell::slotFileBlendURLAndDiff()
 {
-	KompareURLDialog* dialog = new KompareURLDialog( &m_sourceURL, &m_destinationURL, this );
+	KompareURLDialog* dialog = new KompareURLDialog( this );
 
-	dialog->setCaption( i18n( "Blend File/Folder With diff Output" ) );
+	dialog->setCaption( i18n( "Blend File/Folder with diff Output" ) );
 	dialog->setFirstGroupBoxTitle( i18n( "File/Folder" ) );
 	dialog->setSecondGroupBoxTitle( i18n( "Diff Output" ) );
 
@@ -376,6 +388,7 @@ void KompareShell::slotFileBlendURLAndDiff()
 		KompareShell* shell = new KompareShell();
 		kapp->ref();
 		shell->show();
+		shell->m_viewPart->setEncoding( dialog->encoding() );
 		shell->blend( m_sourceURL, m_destinationURL );
 	}
 	delete dialog;
@@ -383,7 +396,7 @@ void KompareShell::slotFileBlendURLAndDiff()
 
 void KompareShell::slotFileCompareFiles()
 {
-	KompareURLDialog* dialog = new KompareURLDialog( &m_sourceURL, &m_destinationURL, this );
+	KompareURLDialog* dialog = new KompareURLDialog( this );
 
 	dialog->setCaption( i18n( "Compare Files or Folders" ) );
 	dialog->setFirstGroupBoxTitle( i18n( "Source" ) );
@@ -404,6 +417,8 @@ void KompareShell::slotFileCompareFiles()
 		KompareShell* shell = new KompareShell();
 		kapp->ref();
 		shell->show();
+		kdDebug() << "Damn it, i should be called !!! Oh and encoding is: " << dialog->encoding() << endl;
+		shell->m_viewPart->setEncoding( dialog->encoding() );
 		shell->compare( m_sourceURL, m_destinationURL );
 	}
 	delete dialog;
@@ -420,34 +435,32 @@ void KompareShell::slotFileClose()
 
 void KompareShell::slotShowTextView()
 {
-	if( !m_textViewWidget ) {
+	if ( !m_textViewWidget )
+	{
+		int errCode;
 
-		KService::Ptr ptr = KServiceTypeProfile::preferredService( "text/plain", "KParts/ReadOnlyPart" );
-		if ( ptr == 0 || !ptr->isValid() )
-			return;
-		KLibFactory* factory = KLibLoader::self()->factory( ptr->library().ascii() );
-
-		m_textViewWidget = createDockWidget( i18n("Text View"), ptr->pixmap( KIcon::Small ) );
-
-		if( factory )
-			m_textViewPart = static_cast<KParts::ReadOnlyPart *>(
-			    factory->create(m_textViewWidget, ptr->name().ascii(), "KParts::ReadOnlyPart"));
-
-		if( m_textViewPart ) {
-			m_textViewWidget->setWidget( m_textViewPart->widget() );
-			m_textViewPart->openURL( m_viewPart->url() );
-			connect( m_viewPart, SIGNAL( diffURLChanged() ), SLOT( slotDiffURLChanged() ) );
+		// FIXME: proper error checking
+		m_textViewWidget = createDockWidget( i18n("Text View"), SmallIcon( "text") );
+		m_textViewPart = KParts::ComponentFactory::createPartInstanceFromQuery<KTextEditor::Document>(
+		                 QString::fromLatin1("KTextEditor/Document"),
+		                 QString::null, (QWidget*)this, 0, (QWidget*)this, 0, QStringList(), &errCode );
+		if ( m_textViewPart )
+		{
+			m_textView = m_textViewPart->createView( this, 0 );
+			m_textViewWidget->setWidget( static_cast<QWidget*>(m_textView) );
+			m_textEditIface = editInterface( m_textViewPart );
+			connect( m_viewPart, SIGNAL(diffString(const QString&)),
+			         this, SLOT(slotSetDiffString(const QString&)) );
 		}
 	}
 
 	m_textViewWidget->manualDock( m_mainViewDock, KDockWidget:: DockCenter );
 }
 
-void KompareShell::slotDiffURLChanged()
+void KompareShell::slotSetDiffString( const QString& diffString )
 {
-	if( m_textViewPart ) {
-		m_textViewPart->openURL( m_viewPart->url() );
-	}
+	if ( m_textEditIface )
+		m_textEditIface->setText( diffString );
 }
 
 void KompareShell::optionsConfigureKeys()
@@ -456,7 +469,7 @@ void KompareShell::optionsConfigureKeys()
 
 	dlg.insert( actionCollection() );
 	if ( m_viewPart )
-	  dlg.insert( m_viewPart->actionCollection() );
+		dlg.insert( m_viewPart->actionCollection() );
 
 	dlg.configure();
 }
