@@ -19,13 +19,13 @@
 #define SIGSLOTVIEW_H
 
 #include <qwidget.h>
-#include <qlistview.h>
+#include <klistview.h>
 
 /**
   *@author Richard Moore
   */
 
-class SigSlotView : public QListView  {
+class SigSlotView : public KListView  {
    Q_OBJECT
 public: 
    SigSlotView(QWidget *parent=0, const char *name=0);
