@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2006                                               *
+ *   copyright (C) 2003-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -19,6 +19,7 @@
 #include "enumliteral.h"
 #include "umldoc.h"
 #include "uml.h"
+#include "uniqueid.h"
 #include "clipboard/idchangelog.h"
 
 UMLEnum::UMLEnum(const QString& name, Uml::IDType id) : UMLClassifier(name, id) {
@@ -51,14 +52,23 @@ void UMLEnum::init() {
     setStereotype( "enum" );
 }
 
-UMLObject* UMLEnum::createEnumLiteral() {
-    QString currentName = uniqChildName(Uml::ot_EnumLiteral);
+UMLObject* UMLEnum::createEnumLiteral(const QString& name) {
+    Uml::IDType id = UniqueID::gen();
+    QString currentName;
+    if (name.isNull())  {
+        currentName = uniqChildName(Uml::ot_EnumLiteral);
+    } else {
+        currentName = name;
+    }
+
     UMLEnumLiteral* newEnumLiteral = new UMLEnumLiteral(this, currentName);
 
     bool ok = true;
     bool goodName = false;
 
-    while (ok && !goodName) {
+    //check for name.isNull() stops dialog being shown
+    //when creating enum literal via list view
+    while (ok && !goodName && name.isNull()) {
         ok = newEnumLiteral->showPropertiesDialog( UMLApp::app() );
         QString name = newEnumLiteral->getName();
 
@@ -70,6 +80,7 @@ UMLObject* UMLEnum::createEnumLiteral() {
     }
 
     if (!ok) {
+        delete newEnumLiteral;
         return NULL;
     }
 
@@ -84,14 +95,14 @@ UMLObject* UMLEnum::addEnumLiteral(const QString &name, Uml::IDType id) {
     UMLObject *el = UMLCanvasObject::findChildObject(name);
     if (el != NULL) {
         kDebug() << "UMLEnum::addEnumLiteral: " << name
-                  << " is already present" << endl; 
+                  << " is already present" << endl;
         return el;
     }
     UMLEnumLiteral* literal = new UMLEnumLiteral(this, name, id);
     m_List.append(literal);
-    emit modified();
-    connect(literal,SIGNAL(modified()),this,SIGNAL(modified()));
+    UMLObject::emitModified();
     emit enumLiteralAdded(literal);
+    connect(literal,SIGNAL(modified()),this,SIGNAL(modified()));
     return literal;
 }
 
@@ -101,9 +112,9 @@ bool UMLEnum::addEnumLiteral(UMLEnumLiteral* literal, IDChangeLog* Log /* = 0*/)
         literal->parent()->removeChild(literal);
         this->insertChild(literal);
         m_List.append(literal);
-        emit modified();
-        connect(literal,SIGNAL(modified()),this,SIGNAL(modified()));
+        UMLObject::emitModified();
         emit enumLiteralAdded(literal);
+        connect(literal,SIGNAL(modified()),this,SIGNAL(modified()));
         return true;
     } else if (Log) {
         Log->removeChangeByNewID( literal->getID() );
@@ -122,9 +133,9 @@ bool UMLEnum::addEnumLiteral(UMLEnumLiteral* literal, int position) {
         } else {
             m_List.append(literal);
         }
-        emit modified();
-        connect(literal,SIGNAL(modified()),this,SIGNAL(modified()));
+        UMLObject::emitModified();
         emit enumLiteralAdded(literal);
+        connect(literal,SIGNAL(modified()),this,SIGNAL(modified()));
         return true;
     }
     return false;
@@ -136,7 +147,7 @@ int UMLEnum::removeEnumLiteral(UMLEnumLiteral* literal) {
         return -1;
     }
     emit enumLiteralRemoved(literal);
-    emit modified();
+    UMLObject::emitModified();
     // If we are deleting the object, then we don't need to disconnect..this is done auto-magically
     // for us by QObject. -b.t.
     // disconnect(a,SIGNAL(modified()),this,SIGNAL(modified()));
