@@ -35,7 +35,7 @@ public:
      * @param name  The name of the Enum.
      * @param id  The unique id of the Enum.
      */
-    UMLEnum(const QString& name = "", Uml::IDType id = Uml::id_None);
+    explicit UMLEnum(const QString& name = "", Uml::IDType id = Uml::id_None);
 
     /**
      * Standard deconstructor.
@@ -63,7 +63,7 @@ public:
      *
      * @return  The UMLEnum created
      */
-    UMLObject* createEnumLiteral();
+    UMLObject* createEnumLiteral(const QString& name = QString());
 
     /**
      * Adds an enumliteral to the enum.
