@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2003-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2003-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef ENUMLITERAL_H
@@ -36,7 +33,8 @@ public:
      * @param name              The name of this UMLEnumLiteral.
      * @param id                The unique id given to this UMLEnumLiteral.
      */
-    UMLEnumLiteral(const UMLObject* parent, QString name, Uml::IDType id = Uml::id_None);
+    UMLEnumLiteral(const UMLObject* parent,
+                   const QString& name, Uml::IDType id = Uml::id_None);
 
     /**
      * Sets up an enum literal.
@@ -74,7 +72,7 @@ public:
     /**
      * Display the properties configuration dialog for the enum literal.
      */
-    bool showPropertiesDialogue(QWidget* parent);
+    bool showPropertiesDialog(QWidget* parent);
 
 protected:
     /**
