@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -62,6 +62,7 @@ public:
      * Constructs a MessageWidget.
      *
      * @param view              The parent to this class.
+     * @param sequenceMessageType The Uml::Sequence_Message_Type of this message widget
      * @param id                The ID to assign (-1 will prompt a new ID.)
      */
     MessageWidget(UMLView * view, Uml::Sequence_Message_Type sequenceMessageType, Uml::IDType id = Uml::id_None);
@@ -112,6 +113,7 @@ public:
      * Sets the related widget on the given side.
      *
      * @param ow        The ObjectWidget we are related to.
+     * @param role      The Uml::Role_Type to be set for the ObjectWidget
      */
     void setWidget(ObjectWidget * ow, Uml::Role_Type role) ;
 
@@ -214,7 +216,7 @@ public:
      * Activates a MessageWidget.  Connects its m_pOw[] pointers
      * to UMLObjects and also send signals about its FloatingTextWidget.
      */
-    void activate(IDChangeLog * Log = 0);
+    bool activate(IDChangeLog * Log = 0);
 
     /**
      * Calculates the size of the widget by calling
@@ -320,12 +322,12 @@ public:
     int onWidget(const QPoint & p);
 
     /**
-     * Saves to the <messagewidget> XMI element.
+     * Saves to the "messagewidget" XMI element.
      */
     void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
 
     /**
-     * Loads from the <messagewidget> XMI element.
+     * Loads from the "messagewidget" XMI element.
      */
     bool loadFromXMI( QDomElement & qElement );
 
@@ -378,6 +380,13 @@ private:
     ObjectWidget * m_pOw[2];
     FloatingTextWidget * m_pFText;
     int m_nY;
+    /**
+     * The following variables are used by loadFromXMI() as an intermediate
+     * store. activate() resolves the IDs, i.e. after activate() the variables
+     * m_pOw[] and m_pFText can be used.
+     */
+    Uml::IDType m_widgetAId, m_widgetBId, m_textId;
+
 public slots:
     void slotWidgetMoved(Uml::IDType id);
     void slotMenuSelection(int sel);
