@@ -5,17 +5,23 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2003-2006                                                *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *   copyright (C) 2003-2007                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
+// own header
+#include "umlrole.h"
+
+// qt/kde includes
 #include <kdebug.h>
 #include <qregexp.h>
-#include "umlrole.h"
+
+// local includes
 #include "association.h"
 #include "umldoc.h"
 #include "uml.h"
 
+
 // constructor
 UMLRole::UMLRole(UMLAssociation * parent, UMLObject * parentObj, Uml::Role_Type role)
         : UMLObject(const_cast<UMLAssociation*>(parent))
@@ -58,24 +64,24 @@ void UMLRole::setObject (UMLObject *obj) {
     // parent objects. In fact, there is probably good reason
     // to only take UMLClassifiers here, but I'll leave it more open
     // for the time being. -b.t.
-    if(obj && dynamic_cast<UMLRole*>(obj))
-    {
-        kdError()<<"ERROR: UMLRole cant setObject() to another UMLRole!, ignoring"<<endl;
+    if (obj && dynamic_cast<UMLRole*>(obj)) {
+        kError() << "UMLRole(" << ID2STR(m_nId) << ") cannot setObject() to another UMLRole("
+            << ID2STR(obj->getID()) << ")" << endl;
         return;
     }
 
     m_pSecondary = obj;
-    emit modified();
+    UMLObject::emitModified();
 }
 
 void UMLRole::setChangeability (Uml::Changeability_Type value) {
     m_Changeability = value;
-    emit modified();
+    UMLObject::emitModified();
 }
 
 void UMLRole::setMultiplicity ( const QString &multi ) {
     m_Multi = multi;
-    emit modified();
+    UMLObject::emitModified();
 }
 
 Uml::Role_Type UMLRole::getRole() {
@@ -100,7 +106,7 @@ void UMLRole::saveToXMI( QDomDocument & qDoc, QDomElement & qElement ) {
     if (m_pSecondary)
         roleElement.setAttribute( "type", ID2STR(m_pSecondary->getID()) );
     else
-        kdError() << "UMLRole::saveToXMI(id " << ID2STR(m_nId)
+        kError() << "UMLRole::saveToXMI(id " << ID2STR(m_nId)
         << "): m_pSecondary is NULL" << endl;
     if (!m_Multi.isEmpty())
         roleElement.setAttribute("multiplicity", m_Multi);
@@ -133,9 +139,9 @@ void UMLRole::saveToXMI( QDomDocument & qDoc, QDomElement & qElement ) {
             roleElement.setAttribute("relationship", "true");
         }
     }
-    
+
     roleElement.setAttribute("visibility", getVisibility().toString(false));
-    
+
     switch (m_Changeability) {
     case Uml::chg_Frozen:
         roleElement.setAttribute("changeability", "frozen");
@@ -155,7 +161,7 @@ bool UMLRole::load( QDomElement & element ) {
     QString type = element.attribute("type", "");
     if (!type.isEmpty()) {
         if (!m_SecondaryId.isEmpty())
-            kdWarning() << "UMLRole::load: overwriting old m_SecondaryId \""
+            kWarning() << "UMLRole::load: overwriting old m_SecondaryId \""
             << m_SecondaryId << " with new value \""
             << type << "\"" << endl;
         m_SecondaryId = type;
@@ -245,9 +251,9 @@ bool UMLRole::load( QDomElement & element ) {
         }
     }
     if (!m_Multi.isEmpty())
-        kdDebug() << "UMLRole::load(" << m_Name << "): m_Multi is " << m_Multi << endl;
+        kDebug() << "UMLRole::load(" << m_Name << "): m_Multi is " << m_Multi << endl;
     if (m_SecondaryId.isEmpty()) {
-        kdError() << "UMLRole::load: type not given or illegal" << endl;
+        kError() << "UMLRole::load(" << m_Name << "): type not given or illegal" << endl;
         return false;
     }
     UMLObject * obj;
