@@ -5,13 +5,15 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
-//qt include files
+// own header
+#include "worktoolbar.h"
 
-//kde include files
+// qt/kde include files
+#include <qmainwindow.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
@@ -170,6 +172,11 @@ void WorkToolBar::buttonChanged(int b) {
     ToolBar_Buttons tbb = (ToolBar_Buttons)b;
     if (tbb == tbb_Arrow && m_CurrentButtonID == tbb_Arrow) {
         toggleButton(tbb_Arrow);
+
+        // signal needed, in the case ( when switching diagrams ) that
+        // Arrow Button gets activated, but the toolBarState of the Views may be different
+        emit sigButtonChanged( m_CurrentButtonID );
+
         view->setCursor( currentCursor() );
         return;
     }
